@@ -673,11 +673,11 @@ class CornerHead(BaseDenseHead):
                 self._get_bboxes_single(
                     tl_heats[-1][img_id:img_id + 1, :],
                     br_heats[-1][img_id:img_id + 1, :],
-                    tl_embs[-1][img_id:img_id + 1, :],
-                    br_embs[-1][img_id:img_id + 1, :],
                     tl_offs[-1][img_id:img_id + 1, :],
                     br_offs[-1][img_id:img_id + 1, :],
                     img_metas[img_id],
+                    tl_emb=tl_embs[-1][img_id:img_id + 1, :],
+                    br_emb=br_embs[-1][img_id:img_id + 1, :],
                     rescale=rescale,
                     with_nms=with_nms))
 
@@ -686,11 +686,13 @@ class CornerHead(BaseDenseHead):
     def _get_bboxes_single(self,
                            tl_heat,
                            br_heat,
-                           tl_emb,
-                           br_emb,
                            tl_off,
                            br_off,
                            img_meta,
+                           tl_emb=None,
+                           br_emb=None,
+                           tl_centripetal_shift=None,
+                           br_centripetal_shift=None,
                            rescale=False,
                            with_nms=True):
         """Transform outputs for a single batch item into bbox predictions.
@@ -700,16 +702,20 @@ class CornerHead(BaseDenseHead):
                 shape (N, num_classes, H, W).
             br_heat (Tensor): Bottom-right corner heatmap for current level
                 with shape (N, num_classes, H, W).
-            tl_emb (Tensor): Top-left corner embedding for current level with
-                shape (N, corner_emb_channels, H, W).
-            br_emb (Tensor): Bottom-right corner embedding for current level
-                with shape (N, corner_emb_channels, H, W).
             tl_off (Tensor): Top-left corner offset for current level with
                 shape (N, corner_offset_channels, H, W).
             br_off (Tensor): Bottom-right corner offset for current level with
                 shape (N, corner_offset_channels, H, W).
             img_meta (dict): Meta information of current image, e.g.,
                 image size, scaling factor, etc.
+            tl_emb (Tensor): Top-left corner embedding for current level with
+                shape (N, corner_emb_channels, H, W).
+            br_emb (Tensor): Bottom-right corner embedding for current level
+                with shape (N, corner_emb_channels, H, W).
+            tl_centripetal_shift: Top-left corner's centripetal shift for
+                current level with shape (N, 2, H, W).
+            br_centripetal_shift: Bottom-right corner's centripetal shift for
+                current level with shape (N, 2, H, W).
             rescale (bool): If True, return boxes in original image space.
                 Default: False.
             with_nms (bool): If True, do nms before return boxes.
@@ -725,13 +731,15 @@ class CornerHead(BaseDenseHead):
             br_off=br_off,
             tl_emb=tl_emb,
             br_emb=br_emb,
+            tl_centripetal_shift=tl_centripetal_shift,
+            br_centripetal_shift=br_centripetal_shift,
             img_meta=img_meta,
             k=self.test_cfg.corner_topk,
             kernel=self.test_cfg.local_maximum_kernel,
             distance_threshold=self.test_cfg.distance_threshold)
 
         if rescale:
-            batch_bboxes /= img_meta['scale_factor']
+            batch_bboxes /= batch_bboxes.new_tensor(img_meta['scale_factor'])
 
         bboxes = batch_bboxes.view([-1, 4])
         scores = batch_scores.view([-1, 1])
@@ -754,6 +762,8 @@ class CornerHead(BaseDenseHead):
         return detections, labels
 
     def _bboxes_nms(self, bboxes, labels, cfg):
+        if labels.numel() == 0:
+            return bboxes, labels
         out_bboxes, keep = batched_nms(bboxes[:, :4], bboxes[:, -1], labels,
                                        cfg.nms_cfg)
         out_labels = labels[keep]
