@@ -7,7 +7,7 @@ from mmdet.core.bbox.iou_calculators import bbox_overlaps
 from mmdet.models import HEADS
 from mmdet.models.dense_heads import ATSSHead
 
-eps = 1e-12
+EPS = 1e-12
 try:
     import sklearn.mixture as skm
 except ImportError:
@@ -57,12 +57,29 @@ class PAAHead(ATSSHead):
         topk (int): Select topk samples with smallest loss in
             each level.
         score_voting (bool): Whether to use score voting in post-process.
+        covariance_type : String describing the type of covariance parameters
+            to be used in :class:`sklearn.mixture.GaussianMixture`.
+            It must be one of:
+
+            - 'full': each component has its own general covariance matrix
+            - 'tied': all components share the same general covariance matrix
+            - 'diag': each component has its own diagonal covariance matrix
+            - 'spherical': each component has its own single variance
+            Default: 'diag'. From 'full' to 'spherical', the gmm fitting
+            process is faster yet the performance could be influenced. For most
+            cases, 'diag' should be a good choice.
     """
 
-    def __init__(self, *args, topk=9, score_voting=True, **kwargs):
+    def __init__(self,
+                 *args,
+                 topk=9,
+                 score_voting=True,
+                 covariance_type='diag',
+                 **kwargs):
         # topk used in paa reassign process
         self.topk = topk
         self.with_score_voting = score_voting
+        self.covariance_type = covariance_type
         super(PAAHead, self).__init__(*args, **kwargs)
 
     @force_fp32(apply_to=('cls_scores', 'bbox_preds', 'iou_preds'))
@@ -127,27 +144,25 @@ class PAAHead(ATSSHead):
                                        bboxes_weight, pos_inds)
 
         with torch.no_grad():
-            labels, label_weights, bbox_weights, num_pos = multi_apply(
-                self.paa_reassign,
-                pos_losses_list,
-                labels,
-                labels_weight,
-                bboxes_weight,
-                pos_inds,
-                pos_gt_index,
-                anchor_list,
-            )
+            reassign_labels, reassign_label_weight, \
+                reassign_bbox_weights, num_pos = multi_apply(
+                    self.paa_reassign,
+                    pos_losses_list,
+                    labels,
+                    labels_weight,
+                    bboxes_weight,
+                    pos_inds,
+                    pos_gt_index,
+                    anchor_list)
             num_pos = sum(num_pos)
-            if num_pos == 0:
-                num_pos = len(img_metas)
         # convert all tensor list to a flatten tensor
         cls_scores = torch.cat(cls_scores, 0).view(-1, cls_scores[0].size(-1))
         bbox_preds = torch.cat(bbox_preds, 0).view(-1, bbox_preds[0].size(-1))
         iou_preds = torch.cat(iou_preds, 0).view(-1, iou_preds[0].size(-1))
-        labels = torch.cat(labels, 0).view(-1)
+        labels = torch.cat(reassign_labels, 0).view(-1)
         flatten_anchors = torch.cat(
             [torch.cat(item, 0) for item in anchor_list])
-        labels_weight = torch.cat(labels_weight, 0).view(-1)
+        labels_weight = torch.cat(reassign_label_weight, 0).view(-1)
         bboxes_target = torch.cat(bboxes_target,
                                   0).view(-1, bboxes_target[0].size(-1))
 
@@ -156,7 +171,10 @@ class PAAHead(ATSSHead):
                             (labels < self.num_classes)).nonzero().reshape(-1)
 
         losses_cls = self.loss_cls(
-            cls_scores, labels, labels_weight, avg_factor=num_pos)
+            cls_scores,
+            labels,
+            labels_weight,
+            avg_factor=max(num_pos, len(img_metas)))  # avoid num_pos=0
         if num_pos:
             pos_bbox_pred = self.bbox_coder.decode(
                 flatten_anchors[pos_inds_flatten],
@@ -171,7 +189,7 @@ class PAAHead(ATSSHead):
             losses_bbox = self.loss_bbox(
                 pos_bbox_pred,
                 pos_bbox_target,
-                iou_target.clamp(min=eps),
+                iou_target.clamp(min=EPS),
                 avg_factor=iou_target.sum())
         else:
             losses_iou = iou_preds.sum() * 0
@@ -270,7 +288,9 @@ class PAAHead(ATSSHead):
         """
         if not len(pos_inds):
             return label, label_weight, bbox_weight, 0
-
+        label = label.clone()
+        label_weight = label_weight.clone()
+        bbox_weight = bbox_weight.clone()
         num_gt = pos_gt_inds.max() + 1
         num_level = len(anchors)
         num_anchors_each_level = [item.size(0) for item in anchors]
@@ -281,8 +301,8 @@ class PAAHead(ATSSHead):
             mask = (pos_inds >= inds_level_interval[i]) & (
                 pos_inds < inds_level_interval[i + 1])
             pos_level_mask.append(mask)
-        pos_inds_after_paa = []
-        ignore_inds_after_paa = []
+        pos_inds_after_paa = [label.new_tensor([])]
+        ignore_inds_after_paa = [label.new_tensor([])]
         for gt_ind in range(num_gt):
             pos_inds_gmm = []
             pos_loss_gmm = []
@@ -304,9 +324,15 @@ class PAAHead(ATSSHead):
             pos_inds_gmm = pos_inds_gmm[sort_inds]
             pos_loss_gmm = pos_loss_gmm.view(-1, 1).cpu().numpy()
             min_loss, max_loss = pos_loss_gmm.min(), pos_loss_gmm.max()
-            means_init = [[min_loss], [max_loss]]
-            weights_init = [0.5, 0.5]
-            precisions_init = [[[1.0]], [[1.0]]]
+            means_init = np.array([min_loss, max_loss]).reshape(2, 1)
+            weights_init = np.array([0.5, 0.5])
+            precisions_init = np.array([1.0, 1.0]).reshape(2, 1, 1)  # full
+            if self.covariance_type == 'spherical':
+                precisions_init = precisions_init.reshape(2)
+            elif self.covariance_type == 'diag':
+                precisions_init = precisions_init.reshape(2, 1)
+            elif self.covariance_type == 'tied':
+                precisions_init = np.array([[1.0]])
             if skm is None:
                 raise ImportError('Please run "pip install sklearn" '
                                   'to install sklearn first.')
@@ -314,7 +340,8 @@ class PAAHead(ATSSHead):
                 2,
                 weights_init=weights_init,
                 means_init=means_init,
-                precisions_init=precisions_init)
+                precisions_init=precisions_init,
+                covariance_type=self.covariance_type)
             gmm.fit(pos_loss_gmm)
             gmm_assignment = gmm.predict(pos_loss_gmm)
             scores = gmm.score_samples(pos_loss_gmm)
@@ -552,7 +579,7 @@ class PAAHead(ATSSHead):
             cfg.nms,
             cfg.max_per_img,
             score_factors=None)
-        if self.with_score_voting:
+        if self.with_score_voting and len(det_bboxes) > 0:
             det_bboxes, det_labels = self.score_voting(det_bboxes, det_labels,
                                                        mlvl_bboxes,
                                                        mlvl_nms_scores,
